# A Friendly Task Scheduler Frontend

## Introduction

## Installation

```shell
pip install tsq
```

Cutting edge version from the repository:
```shell
pip install git+https://github.com/admk/tsq.git
```
